/****************************************************************************
** Meta object code from reading C++ file 'manhattanstyle.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../texstudio-4.9.6/src/manhattanstyle.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'manhattanstyle.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14ManhattanStyleE_t {};
} // unnamed namespace

template <> constexpr inline auto ManhattanStyle::qt_create_metaobjectdata<qt_meta_tag_ZN14ManhattanStyleE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ManhattanStyle",
        "standardIconImplementation",
        "QIcon",
        "",
        "StandardPixmap",
        "standardIcon",
        "const QStyleOption*",
        "option",
        "const QWidget*",
        "widget",
        "layoutSpacingImplementation",
        "QSizePolicy::ControlType",
        "control1",
        "control2",
        "Qt::Orientation",
        "orientation"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'standardIconImplementation'
        QtMocHelpers::SlotData<QIcon(StandardPixmap, const QStyleOption *, const QWidget *) const>(1, 3, QMC::AccessProtected, 0x80000000 | 2, {{
            { 0x80000000 | 4, 5 }, { 0x80000000 | 6, 7 }, { 0x80000000 | 8, 9 },
        }}),
        // Slot 'layoutSpacingImplementation'
        QtMocHelpers::SlotData<int(QSizePolicy::ControlType, QSizePolicy::ControlType, Qt::Orientation, const QStyleOption *, const QWidget *) const>(10, 3, QMC::AccessProtected, QMetaType::Int, {{
            { 0x80000000 | 11, 12 }, { 0x80000000 | 11, 13 }, { 0x80000000 | 14, 15 }, { 0x80000000 | 6, 7 },
            { 0x80000000 | 8, 9 },
        }}),
        // Slot 'layoutSpacingImplementation'
        QtMocHelpers::SlotData<int(QSizePolicy::ControlType, QSizePolicy::ControlType, Qt::Orientation, const QStyleOption *) const>(10, 3, QMC::AccessProtected | QMC::MethodCloned, QMetaType::Int, {{
            { 0x80000000 | 11, 12 }, { 0x80000000 | 11, 13 }, { 0x80000000 | 14, 15 }, { 0x80000000 | 6, 7 },
        }}),
        // Slot 'layoutSpacingImplementation'
        QtMocHelpers::SlotData<int(QSizePolicy::ControlType, QSizePolicy::ControlType, Qt::Orientation) const>(10, 3, QMC::AccessProtected | QMC::MethodCloned, QMetaType::Int, {{
            { 0x80000000 | 11, 12 }, { 0x80000000 | 11, 13 }, { 0x80000000 | 14, 15 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ManhattanStyle, qt_meta_tag_ZN14ManhattanStyleE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ManhattanStyle::staticMetaObject = { {
    QMetaObject::SuperData::link<QProxyStyle::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14ManhattanStyleE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14ManhattanStyleE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14ManhattanStyleE_t>.metaTypes,
    nullptr
} };

void ManhattanStyle::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ManhattanStyle *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QIcon _r = _t->standardIconImplementation((*reinterpret_cast<std::add_pointer_t<StandardPixmap>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<const QStyleOption*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<const QWidget*>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QIcon*>(_a[0]) = std::move(_r); }  break;
        case 1: { int _r = _t->layoutSpacingImplementation((*reinterpret_cast<std::add_pointer_t<QSizePolicy::ControlType>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QSizePolicy::ControlType>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<Qt::Orientation>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<const QStyleOption*>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<const QWidget*>>(_a[5])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 2: { int _r = _t->layoutSpacingImplementation((*reinterpret_cast<std::add_pointer_t<QSizePolicy::ControlType>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QSizePolicy::ControlType>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<Qt::Orientation>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<const QStyleOption*>>(_a[4])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 3: { int _r = _t->layoutSpacingImplementation((*reinterpret_cast<std::add_pointer_t<QSizePolicy::ControlType>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QSizePolicy::ControlType>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<Qt::Orientation>>(_a[3])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}

const QMetaObject *ManhattanStyle::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ManhattanStyle::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14ManhattanStyleE_t>.strings))
        return static_cast<void*>(this);
    return QProxyStyle::qt_metacast(_clname);
}

int ManhattanStyle::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QProxyStyle::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 4;
    }
    return _id;
}
QT_WARNING_POP
